#!/usr/bin/python3.10
# -*-coding:Utf-8 -*

#==============================================================================
# TENET: AMR CTR at 'Net Expansion' level
#------------------------------------------------------------------------------
# Module grouping compositional transduction rule_sets (CTR) for the analysis of 
# AMR structures, at 'Net Expansion' level
#==============================================================================

#==============================================================================
# Query Builder Imports
#==============================================================================

#import query_builder.construct as construct
from query_builder.builders import *
from query_builder.element.net import Net


#==============================================================================
# CTR Set (CTR as Sparql querries)
#==============================================================================

rule_set = {}

 
# ---------------------------------------------
# Net Expansion: Mod Phenomena Application
# ---------------------------------------------

rule_set['mod-phenomena-application-1'] = {
    'label': "mod-phenomena-application-1",
    'comment': ("Apply mod phenomena (step 1) to: ", 
                " (+) initialize composite class construction. "),
    'construction': f"""
        {composite_class_net.construct(base_node=class_net_1.base_node, 
                                       class_name='?newClassName',
                                       mother_class_net=class_net_1.id)}
        {composite_class_net.compose(class_net_1, class_net_2)}     
    """,
    'clause': f"""
        # *** Identify Mod(c1:Class, c2:Class) ***
        {class_net_1.identify_net()}
        {class_net_1.identify_relation('amr:role_mod', class_net_2.id)} 
        {class_net_2.identify_net()}  
        
        # *** Identify variable label of base leaf ***
        {class_net_1.base_node} a amr:AMR_Leaf ;
            amr:hasVariable ?variable.
        ?variable amr:label ?varLabel.
    """,
    'binding': f"""
		# -- New Class Name
		BIND (CONCAT({class_net_2.class_name}, '-', {class_net_1.class_name}) 
                AS ?newClassName).
        
        {composite_class_net.bind_uri('?newClassName', '?varLabel')}
    """
}

rule_set['mod-phenomena-application-2'] = {
    'label': "mod-phenomena-application-2",
    'comment': ("Apply mod phenomena (step 2) to: ", 
                " (+) complete Composite Class Net for relation propagation"),
    'construction': f"""
        {composite_class_net.define_structure()}     
        {composite_class_net.propagate_relations()}
    """,
    'clause': f"""
        # *** Identify CompositeClass without relation propagated ***
        {composite_class_net.identify_net()}
        {composite_class_net.filter_already_processed_net(Net.RELATION_PROPAGATED)}
        
        # *** Complete clauses for net construction ***
        {composite_class_net.complete_clauses_for_construction()}
    """,
    'binding': f"""
    """
}

rule_set['mod-phenomena-application-3'] = {
    'label': "mod-phenomena-application-3",
    'comment': ("Apply mod phenomena (step 3) to: ",
                " (+) initialize Individual Net construction"),
    'construction': f"""
        {individual_net.construct(base_node=class_net_2.base_node, 
                                  base_class_name='"Feature"',
                                  individual_label='?newIndividualLabel')}
        {individual_net.compose(class_net_2)} 
        {individual_net.define_structure()}      
    """,
    'clause': f"""
        # *** Identify Mod(:Class, c2:Class) ***
        ?net amr:role_mod {class_net_2.id}.
        {class_net_2.identify_net()}  
        
        # *** Identify variable label of base leaf ***
        {class_net_2.base_node} a amr:AMR_Leaf ;
            amr:hasVariable ?variable.
        ?variable amr:label ?varLabel.
        
        # *** Complete clauses for net construction ***
        {individual_net.complete_clauses_for_construction()}
    """,
    'binding': f"""
		# -- New Individual Label
		BIND (STR({class_net_2.class_name}) AS ?newIndividualLabel).
        
        {individual_net.bind_uri('?newIndividualLabel', '?varLabel')}
    """
}

rule_set['mod-phenomena-application-4'] = {
    'label': "mod-phenomena-application-4",
    'comment': ("Apply mod phenomena (step 4) to: ",
                " (4) complete Composite Class Net by adding restrictions"),
    'construction': f"""   
        {composite_class_net.add_attribute(restriction01=restriction_net.id)}
    """,
    'clause': f"""
        # *** Identify CompositeClass in progress step INIT ***
        {composite_class_net.identify_net()}
        {composite_class_net.filter_already_processed_net(Net.RESTRICTION_ADDED)}
        {logical_set_net.identify_net()}
        {composite_class_net.identify_composante(logical_set_net.id)}
        
        # *** Identify Restriction ***
        {restriction_net.identify_net()}
        {logical_set_net.identify_restriction(restriction_net.id)}
    """,
    'binding': f"""
    """
}
