#!/usr/bin/python3.10
# -*-coding:Utf-8 -*

#==============================================================================
# TENET: Rule to entity classification (4)
#------------------------------------------------------------------------------
# AMR rule to classify classes as entities from degree arguments
#==============================================================================

from rdflib import Graph

import transduction
from transduction import net
from transduction.query_builder import generate_select_query
from transduction.rdfterm_computer import produce_uriref, produce_literal

ENTITY_CLASS_TYPE = 'base-out:Entity'


#==============================================================================
# Pattern Search: modality_phenomena
#==============================================================================

def __search_pattern(graph):
    query_code = ''
    result_set = []
    select_data_list = ['?class_net']
    for arg_relation in ['amr:role_ARG1', 'amr:role_ARG5']:
        clause_list = [f'?phenomena_net a net:Phenomena_Net .',
                       f'?phenomena_net net:targetArgumentNode ?rightLeaf .',
                       f'?phenomena_net net:hasPhenomenaType amr:phenomena_degree .',
                       '?class_net a [rdfs:subClassOf* net:Class_Net] .',
                       f'?phenomena_net {arg_relation} ?rightClassNet .'
                       ]
        query_code = generate_select_query(graph, select_data_list, clause_list)
        result_set += graph.query(query_code)
    return query_code, result_set


#==============================================================================
# Useful Computation Method(s)
#==============================================================================  

# None
    
    
#==============================================================================
# Construct Method(s)
#==============================================================================

def __classify_net_as_entity(graph, net_uri):
    class_net = net.ClassNet(graph, uri=net_uri)
    class_net.class_type = ENTITY_CLASS_TYPE    
    return class_net.generate_triple_definition()
  
    
#==============================================================================
# Main Method
#==============================================================================

def classify_entity_from_degree_arguments(graph):
    
    # -- Rule Initialization 
    rule_label = 'classify class net as entity from degree arguments' 
    rule_triple_list = []
    
    # -- Search for patterns 
    _, pattern_set = __search_pattern(graph)
    
    # -- Pattern Analysis
    for pattern in pattern_set:
        new_triple = __classify_net_as_entity(graph, pattern.class_net)
        rule_triple_list += new_triple
    
    return rule_label, rule_triple_list