#!/usr/bin/python3.10
# -*-coding:Utf-8 -*

#==============================================================================
# TENET: Rule to associate mother relation between classes from domain relation
#------------------------------------------------------------------------------
# AMR rule to classify classes as mothers based on the domain relation
#==============================================================================

from rdflib import Graph

import transduction
from transduction import net
from transduction.query_builder import generate_select_query
from transduction.rdfterm_computer import produce_uriref, produce_literal



#==============================================================================
# Pattern Search: domain
#==============================================================================

def __search_pattern(graph):
    query_code = ''
    result_set = []
    for arg_relation in ['amr:role_domain']:
        select_data_list = ['?leftClassNet', '?rightClassNet']
        clause_list = [f'?leftClassNet a [rdfs:subClassOf* net:Class_Net].',
                       f'?rightClassNet a [rdfs:subClassOf* net:Class_Net].',
                       f'?leftClassNet {arg_relation} ?rightClassNet.']
        query_code = generate_select_query(graph, select_data_list, clause_list)
        result_set += graph.query(query_code)
    return query_code, result_set


#==============================================================================
# Useful Computation Method(s)
#==============================================================================  

# None
    
    
#==============================================================================
# Construct Method(s)
#==============================================================================

def __associate_mother_relation(graph, left_net_uri, right_net_uri):
    left_class_net = net.ClassNet(graph, uri=left_net_uri)
    right_class_net = net.ClassNet(graph, uri=right_net_uri)
    left_class_net.mother_class_net = right_class_net.uri
    return left_class_net.generate_triple_definition()



#==============================================================================
# Main Rule Method: classify-net-from-domain
#==============================================================================

def classify_mother_from_domain_relation(graph):
   
    # -- Rule Initialization 
    rule_label = "Associate mother to class net from :domain relation"
    rule_triple_list = []
    
    query_code, pattern_set = __search_pattern(graph)
    
    for pattern in pattern_set:
        left_class_net_uri = str(pattern[0].toPython())
        right_class_net_uri = str(pattern[1].toPython())
        
        # Associate mother relation between classes
        new_triples = __associate_mother_relation(graph, left_class_net_uri, right_class_net_uri)
        rule_triple_list.extend(new_triples)
    
    return rule_label, rule_triple_list

