#!/usr/bin/python3.10
# -*-coding:Utf-8 -*

#==============================================================================
# TENET: Composition Transduction Scheme for AMR analysis
#------------------------------------------------------------------------------
# Composition Transduction Scheme (CTS) using CTR (rules) for analysis of AMR 
# structure.
#==============================================================================

import scheme.amr_master_rule as rule

#==============================================================================
# Rule Directory
#==============================================================================

rule_dir = 'amr_master_rule/'


#==============================================================================
# Prefix using in CTR
#==============================================================================

prefix_list = [('owl', '<http://www.w3.org/2002/07/owl#>'),
               ('odrl', '<http://www.w3.org/ns/odrl/2/>'),
               ('cc', '<https://creativecommons.org/ns#>'),
               ('rdf', '<http://www.w3.org/1999/02/22-rdf-syntax-ns#>'),
               ('rdfs', '<http://www.w3.org/2000/01/rdf-schema#>'),
               ('xsd', '<http://www.w3.org/2001/XMLSchema#>'),
               ('amr', '<https://amr.tetras-libre.fr/rdf/schema#>'),
               ('ns1', '<http://amr.isi.edu/frames/ld/v1.2.2/>'),
               ('ns2', '<http://amr.isi.edu/rdf/amr-terms#>'),
               ('ns3', '<http://amr.isi.edu/rdf/core-amr#>'),
               ('ns4', '<http://amr.isi.edu/entity-types#>'),
               ('net', '<https://tenet.tetras-libre.fr/semantic-net#>'),
               ('cprm', '<https://tenet.tetras-libre.fr/config/parameters#>'),
               ('fprm', '<https://tenet.tetras-libre.fr/frame/parameters#>'),
               ('base-out', '<https://tenet.tetras-libre.fr/base-ontology#>'),
               ('ext-out', '<https://tenet.tetras-libre.fr/extract-result#>')]


#==============================================================================
# Sequences
#==============================================================================

# ---------------------------------------------
# Refinement Sequence(s)
# ---------------------------------------------

default_refinement_sequence = {
    'label': 'default-refinement-sequence',
    'comment': 'sequence without rule',
    'rule_key_list': []
    }



# ---------------------------------------------
# Preprocessing Sequence(s)
# ---------------------------------------------

# nov_amrld_correcting_sequence = {
#     'label': 'amrld-correcting-sequence',
#     'comment': 'correction of AMR-LD data for some known anomalies',
#     'rule_key_list': [#'fix-amr-bug-about-system-solar-planet'
#                       ]
#     }

# nov_amr_reification_sequence = {
#     'label': 'amr-reification-sequence',
#     'comment': 'AMR reification from AMR-Linked-Data to AMR (tenet) structure',
#     'rule_key_list': [#'reclassify-concept-1',
#                       #'reclassify-concept-2',
#                       #'reclassify-concept-3',
#                       #'reclassify-concept-4',
#                       #'reclassify-concept-5',
#                       #'reify-roles-as-concept',
#                       #'reclassify-existing-variable',
#                       #'add-new-variable-for-reified-concept',
#                       #'add-amr-leaf-for-reclassified-concept',
#                       #'add-amr-leaf-for-reified-concept',
#                       #'add-amr-edge-for-core-relation',
#                       #'add-amr-edge-for-reified-concept',
#                       #'add-amr-edge-for-name-relation',
#                       #'add-amr-edge-for-quant-relation',
#                       #'add-amr-edge-for-polarity-relation',
#                       #'update-amr-edge-role-1',
#                       #'add-amr-root'
#                       ]
#     }

amr_bug_fixing_sequence = ['Bug fixing for some known anomalies of AMR-LD data',
                           rule.fix_amr_bug_1
                           ]

amr_reification_sequence = ['AMR reification from AMR-Linked-Data to AMR (tenet) structure',
                            rule.reclassify_concept_1,
                            rule.reclassify_concept_2,
                            rule.reclassify_concept_3,
                            rule.reclassify_concept_4,
                            rule.reclassify_concept_5,
                            rule.reify_roles_as_concept,
                            rule.reclassify_existing_variable,
                            rule.add_new_variable_for_reified_concept,
                            rule.add_amr_leaf_for_reclassified_concept,
                            rule.add_amr_leaf_for_reified_concept,
                            rule.add_amr_edge_for_core_relation,
                            rule.add_amr_edge_for_reified_concept,
                            rule.add_amr_edge_for_name_relation,
                            rule.add_amr_edge_for_quant_relation,
                            rule.add_amr_edge_for_polarity_relation,
                            rule.update_amr_edge_role_1,
                            rule.add_amr_root
                            ]

# ---------------------------------------------
# Transduction Sequences
# ---------------------------------------------

atomic_extraction_sequence = ['atomic extraction sequence',
                              rule.extract_atom_class,
                              rule.extract_atom_individual,
                              rule.extract_atom_property,
                              rule.extract_atom_value,
                              rule.extract_atom_phenomena,
                              rule.propagate_atom_relation]

classification_sequence_1 = ['classification sequence (1)',
                             rule.classify_modality_phenomena,
                             rule.reclassify_argument_property_to_class
                             ]

phenomena_analyze_sequence_1 = ['phenomena analyze sequence (1)',
                                rule.analyze_phenomena_polarity_1,
                                rule.analyze_phenomena_polarity_2,
                                rule.analyze_phenomena_polarity_3,
                                rule.analyze_phenomena_polarity_4,
                                rule.analyze_phenomena_polarity_5,
                                rule.analyze_phenomena_mod_1,
                                rule.classify_modality_phenomena
                                ]

phenomena_analyze_sequence_2 = ['phenomena analyze sequence (2)',
                                rule.analyze_phenomena_or_1,
                                rule.analyze_phenomena_or_2,
                                rule.analyze_phenomena_and_1,
                                rule.analyze_phenomena_and_2]

composite_class_extraction_sequence = ['composite class extraction sequence',
                                       rule.extract_composite_class_1,
                                       rule.extract_composite_class_2]

classification_sequence_2 = ['classification sequence (2)',
                             rule.classify_entity_from_core_arguments,
                             rule.classify_entity_from_part_relation,
                             rule.classify_entity_from_degree_arguments,
                             rule.classify_mother_from_domain_relation,
                             rule.propagate_individual_1,
                             rule.propagate_individual_2
                             ]


# # ---------------------------------------------
# # OWL Generation
# # ---------------------------------------------

owl_generation_sequence = ['OWL Generation Sequence',
                           rule.generate_owl_class,
                           rule.generate_owl_property,
                           rule.generate_owl_individual
                           ]



#==============================================================================
# Transduction Scheme
#==============================================================================

scheme = {
    
    'Preprocessing': [default_refinement_sequence,
                      amr_bug_fixing_sequence,
                      amr_reification_sequence,
                      # nov_amrld_correcting_sequence,
                      # nov_amr_reification_sequence
                      ],
    
    'Transduction': [default_refinement_sequence,
                     atomic_extraction_sequence,
                     classification_sequence_1,
                     phenomena_analyze_sequence_1,
                     phenomena_analyze_sequence_2,
                     composite_class_extraction_sequence,
                     classification_sequence_2],
    
    'Generation': [default_refinement_sequence,
                   owl_generation_sequence]
    
    }


