#!/usr/bin/python3.10
# -*-coding:Utf-8 -*

#==============================================================================
# TENET: Naming Computer
#------------------------------------------------------------------------------
# Class grouping methods to compute names and URI for semantic nets (and their 
# attributes)
#==============================================================================

from rdflib import URIRef


#==============================================================================
# Parameters and Utilities
#==============================================================================

# Property Naming Variants
PROPERTY_NAMING_0 = ''
PROPERTY_NAMING_1 = 'ing'
PROPERTY_NAMING_2 = '-by'
PROPERTY_NAMING_3 = '-of'

def __extract_naming(net, default='none'):
    naming = f'{default}'
    naming_list = net.naming
    if len(naming_list) > 0:
        assert len(naming_list) == 1, f'Houston, we have a problem: too many naming'
        naming = naming_list[0]
    return naming



#==============================================================================
# Method to compute naming for Composite Net
#==============================================================================      

def define_composite_naming_1(net_1, net_2, net_3, 
                              property_naming=PROPERTY_NAMING_0):
    
    name_1 = __extract_naming(net_1, default='something')
    name_2 = __extract_naming(net_2, default='do')
    name_3 = __extract_naming(net_3, default='something')
    
    return f'{name_1}-{name_2}{property_naming}-{name_3}'
        

def define_composite_naming_2(feature_str, net, 
                              property_naming=PROPERTY_NAMING_0):
    
    name_1 = __extract_naming(net, default='something')
    
    return f'{feature_str}-{name_1}{property_naming}'



#==============================================================================
# Method to compute naming for Restriction Net
#==============================================================================  
        

def define_restriction_naming(net_1, net_2):
    
    name_1 = __extract_naming(net_1, default='do')
    name_2 = __extract_naming(net_2, default='something')
    
    return f'{name_1}-{name_2}'



#==============================================================================
# Method to compute naming for Axiom Net
#==============================================================================  
        

def define_axiom_naming(axiom_net, arg_net_list):
    
    naming = f''
    
    # -- Base Axiom Name
    base_axiom_name = f'defaultAxiom'
    axiom_name_list = axiom_net.axiom_name
    if len(axiom_name_list) > 0:
        assert len(axiom_name_list) == 1, f'Houston, we have a problem: too many axiom name'
        base_axiom_name = axiom_name_list[0]
    
    # -- Arguments Ref
    argument_ref = f''
    for arg_net in arg_net_list:
        arg_naming = __extract_naming(arg_net, default='unknow-argument')
        argument_ref += f'_{arg_naming}'
    
    return f'{base_axiom_name}{argument_ref}'
    