#!/usr/bin/python3.10
# -*-coding:Utf-8 -*

#==============================================================================
# TENET: Atom Property
#------------------------------------------------------------------------------
# Class to handle semantic nets 
#==============================================================================

from transduction.net import PropertyNet
from transduction.rdfterm_computer import produce_uriref, produce_literal


#==============================================================================
# Net Class
#==============================================================================

class AtomPropertyNet(PropertyNet):
    """ Class to handle semantic net.
    """
    
    #--------------------------------------------------------------------------
    # Constructor(s)
    #--------------------------------------------------------------------------
           
    def __init__(self, support_graph, uri=None):

        # -- Parent init
        super().__init__(support_graph, uri)
        
        # -- Net Type
        self.type_name = 'atomProperty'
        self.type_id = 'Atom_Property_Net'
        self.type_uri = produce_uriref(self.support_graph, f'net:{self.type_id}')
        
        # -- Net Attributes
        self.attr_list += ['core_role', 'target_argument_node', 'property_type', 
                           'property_name01', 'property_name10', 'property_name12']
        self._core_role = None
        self._target_argument_node = []
        self._property_type = None
        #self._property_name = None
        self._property_name01 = None
        self._property_name10 = None
        self._property_name12 = None

        
    #--------------------------------------------------------------------------
    # Accessors for Net Attributes
    #--------------------------------------------------------------------------
        
    @property
    def core_role(self):
        if self._core_role is None: 
            self._core_role = self.get_value_list_from_graph('_core_role')
            #self._core_role = produce_boolean(None, self._core_role)
        return self._core_role
    
    @core_role.setter
    def core_role(self, new_value):
        self._core_role = self.set_attribute_value_list(new_value, produce_literal)
        
        
    @property
    def target_argument_node(self):
        if self._target_argument_node == []: 
            self._target_argument_node = self.get_value_list_from_graph('_target_argument_node')
        return self._target_argument_node
    
    @target_argument_node.setter
    def target_argument_node(self, new_value):
        self._target_argument_node = self.set_attribute_value_list(new_value, produce_uriref)

        
    @property
    def property_type(self):
        if self._property_type is None: 
            self._property_type = self.get_value_list_from_graph('_property_type')
        return self._property_type
    
    @property_type.setter
    def property_type(self, new_value):
        self._property_type = self.set_attribute_value_list(new_value, produce_uriref)

        
    @property
    def property_name01(self):
        if self._property_name01 is None: 
            self._property_name01 = self.get_value_list_from_graph('_property_name01')
        return self._property_name01
    
    @property_name01.setter
    def property_name01(self, new_value):
        self._property_name01 = self.set_attribute_value_list(new_value, produce_literal)
        
        
    @property
    def property_name10(self):
        if self._property_name10 is None: 
            self._property_name10 = self.get_value_list_from_graph('_property_name10')
        return self._property_name10
    
    @property_name10.setter
    def property_name10(self, new_value):
        self._property_name10 = self.set_attribute_value_list(new_value, produce_literal)

        
    @property
    def property_name12(self):
        if self._property_name12 is None: 
            self._property_name12 = self.get_value_list_from_graph('_property_name12')
        return self._property_name12
    
    @property_name12.setter
    def property_name12(self, new_value):
        self._property_name12 = self.set_attribute_value_list(new_value, produce_literal)
