#!/usr/bin/python3.10
# -*-coding:Utf-8 -*

#==============================================================================
# TENET: Composite Class Net
#------------------------------------------------------------------------------
# Class to handle semantic nets 
#==============================================================================

from transduction.net import ClassNet
from transduction.rdfterm_computer import produce_uriref, produce_literal


#==============================================================================
# Net Class
#==============================================================================

class CompositeClassNet(ClassNet):
    """ Class to handle semantic net.
    """
    
    #--------------------------------------------------------------------------
    # Constructor(s)
    #--------------------------------------------------------------------------
           
    def __init__(self, support_graph, uri=None):

        # -- Parent init
        super().__init__(support_graph, uri)
        
        # -- Net Type
        self.type_name = 'compositeClass'
        self.type_id = 'Composite_Class_Net'
        self.type_uri = produce_uriref(self.support_graph, f'net:{self.type_id}')
        
        # -- Net Attributes
        self.attr_list += ['mother_class_net', 'restriction', 'restriction01']
        self._mother_class_net = None
        self._restriction = []
        self._restriction01 = []
        
        
    #--------------------------------------------------------------------------
    # Accessors for Net Attributes
    #--------------------------------------------------------------------------
        
    @property
    def mother_class_net(self):
        if self._mother_class_net is None: 
            self._mother_class_net = self.get_value_list_from_graph('mother_class_net')
        return self._mother_class_net
    
    @mother_class_net.setter
    def mother_class_net(self, new_value):
        self._mother_class_net = self.set_attribute_value_list(new_value, produce_uriref)

        
    @property
    def restriction(self):
        if self._restriction == []: 
            self._restriction = self.get_value_list_from_graph('restriction')
        return self._restriction
    
    @restriction.setter
    def restriction(self, new_value):
        self._restriction = self.set_attribute_value_list(new_value, produce_uriref)

        
    @property
    def restriction01(self):
        if self._restriction01 == []: 
            self._restriction01 = self.get_value_list_from_graph('restriction01')
        return self._restriction01
    
    @restriction01.setter
    def restriction01(self, new_value):
        self._restriction01 = self.set_attribute_value_list(new_value, produce_uriref)
