#!/usr/bin/python3.10
# -*-coding:Utf-8 -*

#==============================================================================
# TENET: Individual Net
#------------------------------------------------------------------------------
# Class to handle semantic nets 
#==============================================================================

from transduction.net import Net
from transduction.rdfterm_computer import produce_uriref, produce_literal


#==============================================================================
# Net Class
#==============================================================================

class IndividualNet(Net):
    """ Class to handle semantic net.
    """
    
    #--------------------------------------------------------------------------
    # Constructor(s)
    #--------------------------------------------------------------------------
           
    def __init__(self, support_graph, uri=None):

        # -- Parent init
        super().__init__(support_graph, uri)
        
        # -- Net Type
        self.type_name = 'individual'
        self.type_id = 'Individual_Net'
        self.type_uri = produce_uriref(self.support_graph, f'net:{self.type_id}')
        
        # -- Net Attributes
        self.attr_list += ['base_class_name', 'mother_class_net', 'individual_label', 'individual_uri']
        self._base_class_name = None
        self._mother_class_net = []
        self._individual_label = None
        self._individual_uri = None
  
        
    #--------------------------------------------------------------------------
    # Accessors for Net Attributes
    #--------------------------------------------------------------------------
        
    @property
    def base_class_name(self):
        if self._base_class_name is None: 
            self._base_class_name = self.get_value_list_from_graph('_base_class_name')
        return self._base_class_name
    
    @base_class_name.setter
    def base_class_name(self, new_value):
        self._base_class_name = self.set_attribute_value_list(new_value, produce_literal)

        
    @property
    def mother_class_net(self):
        if self._mother_class_net == []: 
            self._mother_class_net = self.get_value_list_from_graph('_mother_class_net')
        return self._mother_class_net
    
    @mother_class_net.setter
    def mother_class_net(self, new_value):
        self._mother_class_net = self.set_attribute_value_list(new_value, produce_uriref)

        
    @property
    def individual_label(self):
        if self._individual_label is None: 
            self._individual_label = self.get_value_list_from_graph('_individual_label')
        return self._individual_label
    
    @individual_label.setter
    def individual_label(self, new_value):
        self._individual_label = self.set_attribute_value_list(new_value, produce_literal)
        
        
    @property
    def individual_uri(self):
        if self._individual_uri is None: 
            self._individual_uri = self.get_value_list_from_graph('individual_uri')
        return self._individual_uri
    
    @individual_uri.setter
    def individual_uri(self, new_value):
        self._individual_uri = self.set_attribute_value_list(new_value, produce_uriref)
